@@ -70,10 +70,10 @@ Kwave::FileContext::FileContext(Kwave::App &app)
     :QObject(),
      m_use_count(1),
      m_application(app),
-     m_top_widget(0),
-     m_main_widget(0),
-     m_signal_manager(0),
-     m_plugin_manager(0),
+     m_top_widget(Q_NULLPTR),
+     m_main_widget(Q_NULLPTR),
+     m_signal_manager(Q_NULLPTR),
+     m_plugin_manager(Q_NULLPTR),
      m_active(true),
      m_last_zoom(0),
      m_last_playback_pos(0),
@@ -95,15 +95,15 @@ Kwave::FileContext::FileContext(Kwave::App &app)
 Kwave::FileContext::~FileContext()
 {
     if (m_main_widget) delete m_main_widget;
-    m_main_widget = 0;
+    m_main_widget = Q_NULLPTR;
 
-    m_top_widget = 0;
+    m_top_widget = Q_NULLPTR;
 
     if (m_plugin_manager) delete m_plugin_manager;
-    m_plugin_manager = 0;
+    m_plugin_manager = Q_NULLPTR;
 
     if (m_signal_manager) delete m_signal_manager;
-    m_signal_manager = 0;
+    m_signal_manager = Q_NULLPTR;
 }
 
 //***************************************************************************
@@ -136,7 +136,7 @@ bool Kwave::FileContext::createMainWidget(const QSize &preferred_size)
     if (!m_main_widget) return false;
     if (!(m_main_widget->isOK())) {
 	delete m_main_widget;
-	m_main_widget = 0;
+        m_main_widget = Q_NULLPTR;
 	return false;
     }
 
@@ -216,7 +216,16 @@ bool Kwave::FileContext::init(Kwave::TopWidget *top_widget)
     // now we are initialized, load all plugins
     Kwave::Splash::showMessage(i18n("Loading plugins..."));
     statusBarMessage(i18n("Loading plugins..."), 0);
-    m_plugin_manager->loadAllPlugins();
+    if (!m_plugin_manager->loadAllPlugins()) {
+	statusBarMessage(i18n("Failed"), 1000);
+	QApplication::restoreOverrideCursor();
+	Kwave::MessageBox::error(top_widget,
+	    i18n("Kwave has not been properly installed. "\
+	         "No plugins found!")
+	);
+	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+	return false;
+    }
     statusBarMessage(i18n("Ready"), 1000);
 
     return true;
@@ -234,9 +243,9 @@ void Kwave::FileContext::setParent(Kwave::TopWidget *top_widget)
 	disconnect(old,  SIGNAL(sigFileContextSwitched(Kwave::FileContext*)),
 	           this, SLOT(contextSwitched(Kwave::FileContext*)));
 
-	if (m_signal_manager) m_signal_manager->setParentWidget(0);
-	if (m_plugin_manager) m_plugin_manager->setParentWidget(0);
-	if (m_main_widget)    m_main_widget->setParent(0);
+        if (m_signal_manager) m_signal_manager->setParentWidget(Q_NULLPTR);
+        if (m_plugin_manager) m_plugin_manager->setParentWidget(Q_NULLPTR);
+        if (m_main_widget)    m_main_widget->setParent(Q_NULLPTR);
 
 	m_active = false;
     }
@@ -404,9 +413,9 @@ int Kwave::FileContext::executeCommand(const QString &line)
     CASE_COMMAND("delayed")
 	if (parser.count() != 2)
 	    return -EINVAL;
-	unsigned int delay = parser.firstParam().toUInt();
-	QString      cmd   = parser.nextParam();
-	enqueueCommand(delay, cmd);
+	unsigned int delay         = parser.firstParam().toUInt();
+	QString      delayed_cmd   = parser.nextParam();
+	enqueueCommand(delay, delayed_cmd);
 	result = 0;
     CASE_COMMAND("loadbatch")
 	result = loadBatch(QUrl(parser.nextParam()));
@@ -417,7 +426,7 @@ int Kwave::FileContext::executeCommand(const QString &line)
 	qDebug("FileContext::executeCommand(): with %d parameter(s)",
 		params.count());
 	result = m_plugin_manager->executePlugin(
-		    name, params.count() ? &params : 0);
+            name, params.count() ? &params : Q_NULLPTR);
     CASE_COMMAND("plugin:execute")
 	QString name(parser.firstParam());
 	QStringList params(parser.remainingParams());
@@ -743,7 +752,7 @@ int Kwave::FileContext::parseCommands(QTextStream &stream)
 	//       or even deletes the current context!
 	result = EAGAIN;
 	Kwave::FileContext *current_ctx = (m_top_widget) ?
-	    m_top_widget->currentContext() : 0;
+	    m_top_widget->currentContext() : Q_NULLPTR;
 	if (current_ctx && (current_ctx != this))
 	    result = m_top_widget->forwardCommand(line);
 
@@ -927,7 +936,7 @@ int Kwave::FileContext::saveFileAs(const QString &filename, bool selection)
 	QUrl current_url;
 	current_url = QUrl(signalName());
 
-	QString what  = Kwave::CodecManager::whatContains(current_url);
+        QString what  = Kwave::CodecManager::mimeTypeOf(current_url);
 	Kwave::Encoder *encoder = Kwave::CodecManager::encoder(what);
 	QString extension; // = "*.wav";
 	if (!encoder) {
@@ -1006,7 +1015,7 @@ int Kwave::FileContext::saveFileAs(const QString &filename, bool selection)
 	Kwave::FileInfo(m_signal_manager->metaData()).get(
 	    Kwave::INF_MIMETYPE).toString();
 
-    QString new_mimetype_name = Kwave::CodecManager::whatContains(url);
+    QString new_mimetype_name = Kwave::CodecManager::mimeTypeOf(url);
 
     if (new_mimetype_name != previous_mimetype_name) {
 	// saving to a different mime type
