@@ -166,7 +166,7 @@ int main(int argc, char **argv)
 #endif
 
     // manually connect the translation catalog, otherwise i18n will not work
-    KLocalizedString::setApplicationDomain(PACKAGE);
+    KLocalizedString::setApplicationDomain(PROJECT_NAME);
 
     QCommandLineParser cmdline;
     cmdline.addHelpOption();
@@ -200,23 +200,26 @@ int main(int argc, char **argv)
     );
 
     KAboutData about(
-	_(PACKAGE),
+	_(PROJECT_NAME),
 	i18n("Kwave"),
-	_(PACKAGE_VERSION),
+	_(KWAVE_VERSION),
 	i18n("A sound editor built on KDE Frameworks 5"),
 	KAboutLicense::GPL_V2,
         i18n("(c) 2016, Thomas Eschenbacher"),
 	QString(),
-	_("http://kwave.sourceforge.net"),
+	_("http://www.kde.org/applications/multimedia/kwave"),
 	_("Thomas.Eschenbacher@gmx.de")
     );
     addDataStrings(about);
 
+    about.setOrganizationDomain(QByteArray("kde.org"));
+    about.setDesktopFileName(QStringLiteral("org.kde.kwave"));
+
     /* use the about data above for this application */
     KAboutData::setApplicationData(about);
 
     /* show some version info */
-    printf("\nThis is %s v%s (compiled for KDE Frameworks %s)\n",
+    printf("\nThis is %s v%s (compiled with KDE Frameworks %s)\n",
 	about.productName().toLatin1().data(),
 	about.version().toLatin1().data(),
 	KXMLGUI_VERSION_STRING
@@ -224,8 +227,8 @@ int main(int argc, char **argv)
 
     app.processCmdline(&cmdline);
     app.setApplicationName(_("kwave"));
-    app.setApplicationVersion(_(PACKAGE_VERSION));
-    app.setOrganizationDomain(_("sourceforge.net"));
+    app.setApplicationVersion(_(KWAVE_VERSION));
+    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true); // enable high dpi support
     cmdline.process(app);
     about.setupCommandLine(&cmdline);
     about.processCommandLine(&cmdline);
