@@ -96,7 +96,7 @@ Kwave::PlayBackOSS::PlayBackOSS()
     m_raw_buffer(),
     m_buffer_size(0),
     m_buffer_used(0),
-    m_encoder(0),
+    m_encoder(Q_NULLPTR),
     m_oss_version(-1)
 {
 }
@@ -316,7 +316,7 @@ int Kwave::PlayBackOSS::close()
 
     // get rid of the old encoder
     if (m_encoder) delete m_encoder;
-    m_encoder = 0;
+    m_encoder = Q_NULLPTR;
 
     return 0;
 }
@@ -471,7 +471,7 @@ void Kwave::PlayBackOSS::format2mode(int format, int &compression,
 		sample_format = Kwave::SampleFormat::Signed;
 		bits          = 24;
 		break;
-	    }
+	    } /* FALLTHROUGH */
 	case AFMT_S32_LE:
 	case AFMT_S32_BE:
 	    if (m_oss_version >= 0x040000) {
@@ -479,7 +479,7 @@ void Kwave::PlayBackOSS::format2mode(int format, int &compression,
 		sample_format = Kwave::SampleFormat::Signed;
 		bits          = 32;
 		break;
-	    }
+            } /* FALLTHROUGH */
 	default:
 	    compression   = -1;
 	    sample_format = Kwave::SampleFormat::Unknown;
